@@ -451,7 +451,7 @@ struct behavior
 
   bool version_set;
   int version;
-  /* The "effective RCS version", for backward compatability,
+  /* The "effective RCS version", for backward compatibility,
      normalized via ‘VERSION’ (i.e., current 0, previous -1, etc).
      ‘version_set’ true means the effective version was set from the
      command-line option ‘-V’.  Additional ‘-V’ results in a warning.
@@ -522,6 +522,7 @@ struct behavior
      (if mmap(2)), or operate on a copy of it in core (if no mmap(2)).
      Otherwise, use standard i/o routines as the fallback.
      Set by env var ‘RCS_MEM_LIMIT’.
+     See also ‘MEMORY_UNLIMITED’.
      -- gnurcs_init  */
 
   struct sff *sff;
@@ -861,6 +862,8 @@ int getRCSINIT (int argc, char **argv, char ***newargv);
 
 /* Idioms.  */
 
+#define MEMORY_UNLIMITED  -1
+
 #define BOG_DIFF   (TYAG_TEMPUNLINK | TYAG_DIFF)
 #define BOG_ZONK   (TYAG_DIRTMPUNLINK | TYAG_TEMPUNLINK)
 #define BOG_FULL   (TYAG_ORCSERROR | BOG_ZONK)
